Saz has been created to make it so easy for anyone to handle any kind of data and use it to dig more and find out about the story behind the features. 
It was written using pandas and tried to use very basic steps which can be understood by anyone, even Python beginners.
Please send me your feedback to this email: siadatisaman@gmail.com



....................................................................

Saz means proper or worthy in ancient Persian(Parsig) (D. N. Mackenzie - A Concise Pahlavi Dictionary (School of Oriental & African Studies) (2002))


